<?php
/*
Plugin Name: Page Peel Ads
plugin URI: https://99robots.com/docs/page-peel-ads/
Description: Page Peel Ads is a beautiful way to add page peel Ads to your WordPress site.
version: 1.1.3
Author: 99 Robots
Author URI: https://99robots.com
License: GPL2
*/

// Exit if accessed directly

if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists('NNR_Page_Peel_Ads') ) :

	/* Adding A Settings link for the plugin on the Settings Page */

	add_filter('plugin_action_links_'.plugin_basename(__FILE__), 'nnr_ppa_add_plugin_page_settings_link');
	function nnr_ppa_add_plugin_page_settings_link( $links ) {
		$links = array_merge(array('<a href="' .
			admin_url( 'admin.php?page=nnr-ppa-dashboard' ) .
			'">' . __('Settings') . '</a>'), $links);
		return $links;
	}

register_activation_hook( __FILE__, 	array('NNR_Page_Peel_Ads', 'register_activation'));
add_action('admin_menu', 				array('NNR_Page_Peel_Ads', 'menu'));
add_action('init', 						array('NNR_Page_Peel_Ads', 'load_textdoamin'));
add_action('wp_head',					array('NNR_Page_Peel_Ads', 'display'), 10, 1);

// Include all the helper libraries

require_once('includes/data-manager/autoload.php');
require_once('includes/display-conditions/autoload.php');
require_once('includes/stats-tracker/autoload.php');

/**
 * NNR_Page_Peel_Ads class.
 */
class NNR_Page_Peel_Ads {

	/**
	 * prefix
	 *
	 * (default value: 'nnr_page_peel_ads_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix = 'nnr_page_peel_ads_';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnr-ppa-')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix_dash = 'nnr-ppa-';

	/**
	 * text_domain
	 *
	 * (default value: '99robots-page-peel-ads')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $text_domain = '99robots-page-peel-ads';

	/**
	 * dashboard_page
	 *
	 * (default value: 'nnr-ppa-dashbaord')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $dashboard_page = 'nnr-ppa-dashboard';

	/**
	 * add_edit_page
	 *
	 * (default value: 'nnr-ppa-add-edit')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $add_edit_page = 'nnr-ppa-add-edit';

	/**
	 * updates_page
	 *
	 * (default value: 'nnr-ppa-updates')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $updates_page = 'nnr-ppa-updates';

	/**
	 * stats_page
	 *
	 * (default value: 'nnr-ppa-stats')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $stats_page = 'nnr-ppa-stats';

	/**
	 * data_manager_table_name
	 *
	 * (default value: 'nnr_page_peel_ads')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $data_manager_table_name = 'nnr_page_peel_ads';

	/**
	 * stats_table_name
	 *
	 * (default value: 'nnr_page_peel_ads_stats')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $stats_table_name = 'nnr_page_peel_ads_stats';

	/**
	 * Returns a default Ad
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function default_data() {
		return array(
			'name'					=> __('My Ad', self::$text_domain),
			'active'				=> 0,
			'start_date'			=> date('Y-m-d H:i:s', mktime(0, 0, 0, date("m"), date("d"), date("Y"))),
			'end_date'				=> date("Y-m-d H:i:s", mktime(0, 0, 0, date("m"), date("d"), date("Y")+20)),
			'display_conditions'	=> array(
				'sitewide'			=> true,
				'post_types'		=> array(
					'post'			=> array(
						'type'		=> 'all',
					),
					'page'			=> array(
						'type'		=> 'none',
					),
					'attachment'	=> array(
						'type'		=> 'none',
					)
				),
				'frontpage'			=> null,
				'taxonomies'		=> null,
				'referrer_type'		=> null,
				'referrer_domain'	=> null,
				'users'				=> null,
				'roles'				=> null,
				'display_screen'	=> null,
			),
			'args'					=> array(
				'ad_type'			=> 'image',
				'ad_image'			=> null,
				'ad_destination_target'	=> null,
				'content_type'		=> 'ad',
				'position'			=> '3',
				'powered_by'		=> true,
				'sticky'			=> true,
				'bouncy'            => true,
				'peel_type'			=> null,
				'background_color'	=> '#fff'
			),
		);
	}

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdoamin() {
		load_plugin_textdomain(self::$text_domain, false, basename( dirname( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Performs tasks needed upon activation
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		// Check if multisite, if so then save as site option

		if ( function_exists('is_multisite') && is_multisite() ) {
			update_site_option(self::$prefix . 'version', NNROBOTS_PAGE_PEEL_ADS_VERSION_NUM);
		} else {
			update_option(self::$prefix . 'version', NNROBOTS_PAGE_PEEL_ADS_VERSION_NUM);
		}

		// Create Table upon activation

		$data_manager = new NNR_Data_Manager_v1( self::$data_manager_table_name );
		$data_manager->create_table();

		$stats_tracker = new NNR_Stats_Tracker_v1( self::$stats_table_name );
		$stats_tracker->create_table();

	}

	/**
	 * Hooks to 'plugin_action_links_' filter
	 *
	 * @since 1.0.0
	 */
	static function settings_link($links) {
		$settings_link = '<a href="admin.php?page=' . self::$dashboard_page . '">' . __('Overlays', self::$text_domain) . '</a>';
		array_unshift($links, $settings_link);
		return $links;
	}


	/**
	 * Outputs the Ad inside the post
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function display() {

		global $post;

		$now = date('Y-m-d h:m:s');

		$data_manager = new NNR_Data_Manager_v1( self::$data_manager_table_name );
		$data = $data_manager->get_data_from_date_range($now, $now);
		$display_manager = new NNR_Display_Conditions_Display_v2();

		$sitewide = array();
		$taxonomies = array();
		$post_ids = array();

		foreach ( $data as $item ) {

			// Sitewide

			if ( $item['display_conditions']['sitewide'] ) {
				$sitewide[] = $item;
				continue;
			}

			if ( $item['display_conditions']['frontpage'] ) {
				$post_ids[] = $item;
				continue;
			}

			// Posts

			if ( $item['display_conditions']['post_types'][$post->post_type]['type'] != 'none' &&
				 $item['display_conditions']['post_types'][$post->post_type]['type'] != 'all' &&
				 $item['display_conditions']['post_types'][$post->post_type]['type'] != 'specific' ) {

				$post_ids[] = $item;
				continue;
			} else {
				$taxonomies[] = $item;
				continue;
			}

		}

		$data = array_merge($post_ids, $taxonomies, $sitewide);

		foreach ( $data as $item ) {
			if ( $display_manager->check_conditions($item['display_conditions']) ) {
				echo self::display_ad($item);
			}
		}
	}

	/**
	 * Display a specific Ad
	 *
	 * @access public
	 * @static
	 * @param mixed $data_id
	 * @return void
	 */
	static function display_ad( $data ){

		$ad_image_src = '';

		if ( $data['args']['ad_type'] == 'image' ) {
			$ad_image_attributes = wp_get_attachment_image_src($data['args']['ad_image'], 'full');

			if( $ad_image_attributes ) {
				$ad_image_src = $ad_image_attributes[0];
			} else {
				$ad_image_src = '';
			}
		} else {
			$ad_image_src = $data['args']['ad_image_link'];
		}

		// Styles

		wp_enqueue_style(self::$prefix_dash . 'css', plugins_url('css/page-peel-ads.css', __FILE__));
		wp_enqueue_style(self::$prefix_dash . 'fontawesome_css', plugins_url('css/font-awesome.min.css', __FILE__));

		// Scripts

		wp_enqueue_script(self::$prefix_dash . 'peelback_js', plugins_url('js/jquery.peelback.js', __FILE__),array('jquery'));
		wp_enqueue_script(self::$prefix_dash . 'js', plugins_url('js/page-peel-ads.js', __FILE__),array('jquery'));
		wp_localize_script(self::$prefix_dash . 'js', 'nnr_ppa_data', array(
			'prefix'					=> self::$prefix_dash,
			'preview'					=> isset($_GET['page']) && $_GET['page'] == self::$dashboard_page ? true : false,
			'ajaxurl'					=> admin_url('admin-ajax.php'),
			'stats_table_name'			=> self::$stats_table_name,
			'data_id'					=> $data['id'],
			'position'					=> $data['args']['position'],
			'peel_image'				=> NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/img/peel-shadow.png',
			'image'						=> $ad_image_src,
			'url'						=> $data['args']['ad_destination_link'],
			'target'					=> $data['args']['ad_destination_target'],
			'rel'						=> isset($data['args']['ad_destination_rel']) && $data['args']['ad_destination_rel'] ? 'rel="nofollow"' : '',
		));

		$direction = array('left', 'top', '0 0', '');

		switch ($data['args']['position'])
		{	case 2:
				$direction = array('right', 'top', '100% 0', '-webkit-transform: scaleX(-1); transform: scaleX(-1);');
				break;
			case 3:
				$direction = array('left', 'bottom', '0 100%', '-webkit-transform: rotate(-90deg); transform: rotate(-90deg);');
				break;
			case 4:
				$direction = array('right', 'bottom', '100% 100%', '-webkit-transform: rotate(-90deg) scaleY(-1); transform: rotate(-90deg) scaleY(-1);');
				break;
		}

		return "<style>
			#nnr-ppa-of
			{	position: " . (isset($data['args']['sticky']) && $data['args']['sticky'] ? 'fixed' : 'absolute') . ";
			}
			#nnr-ppa-clipper,#nnr-ppa-peel-image
			{	transition: all " . (isset($data['args']['bouncy']) && $data['args']['bouncy'] ? '.8s cubic-bezier(.38,2.26,.15,.6);' : '.5s ease-out;')."
			}
			#nnr-ppa-clipper
			{	$direction[0]: -36px;
				$direction[1]: -36px;
				background: {$data['args']['background_color']};
			}
			#nnr-ppa-peelback:hover #nnr-ppa-clipper
			{	$direction[0]: -355px;
				$direction[1]: -355px;
			}
			#nnr-ppa-ad-image
			{	$direction[0]: 50%;
				$direction[1]: 50%;
				transform-origin: $direction[2];
			}
			#nnr-ppa-peel-image,#nnr-ppa-of
			{	$direction[0]: 0;
				$direction[1]: 0;
			}
			#nnr-ppa-peel-image
			{	$direction[3];
			}
			#nnr-ppa-path
			{	fill: {$data['args']['background_color']};
			}
			".'
		</style>';

	}

	/**
	 * Hooks to 'admin_menu'
	 *
	 * @since 1.0.0
	 */
	static function menu() {

		// Dashboard

		add_menu_page(
			__(NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME, self::$text_domain),	// Page Title
			__(NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME, self::$text_domain), 	// Menu Name
	    	'manage_options', 											// Capabilities
	    	self::$dashboard_page, 										// slug
	    	array('NNR_Page_Peel_Ads', 'dashboard'),						// Callback function
	    	plugin_dir_url(__FILE__) . 'img/logo.png" style="width:20px;padding-top: 6px;'
	    );

	    // Dashboard

	    $dashboard_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('All Ads', self::$text_domain), 							// Page title
	    	__('All Ads', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$dashboard_page, 										// slug
	    	array('NNR_Page_Peel_Ads', 'dashboard')						// Callback function
	    );
	    add_action("admin_print_scripts-$dashboard_page_load", array('NNR_Page_Peel_Ads', 'dashboard_scripts'));

	    // Add / Edit

	    $add_edit_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Add New', self::$text_domain), 							// Page title
	    	__('Add New', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$add_edit_page, 										// slug
	    	array('NNR_Page_Peel_Ads', 'add_edit')						// Callback function
	    );
	    add_action("admin_print_scripts-$add_edit_page_load", array('NNR_Page_Peel_Ads', 'add_edit_scripts'));

	    // Stats

	    $stats_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Stats', self::$text_domain), 							// Page title
	    	__('Stats', self::$text_domain), 							// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$stats_page, 											// slug
	    	array('NNR_Page_Peel_Ads', 'stats')							// Callback function
	    );
	    add_action("admin_print_scripts-$stats_page_load", array('NNR_Page_Peel_Ads', 'stats_scripts'));

	    // Updates Page

	    $updates_page_load = add_submenu_page(
	    	self::$dashboard_page, 										// parent slug
	    	__('Updates', self::$text_domain),  						// Page title
	    	__('Updates', self::$text_domain),  						// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$updates_page, 										// slug
	    	array('NNR_Page_Peel_Ads', 'updates')						// Callback function
	    );
	    add_action("admin_print_scripts-$updates_page_load", array('NNR_Page_Peel_Ads', 'updates_scripts'));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function dashboard_scripts() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/settings.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');
	    wp_enqueue_style('wp-color-picker');

		// Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'admin_js', 						NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/dashboard.js', array('wp-color-picker', 'jquery'), false, true );
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_edit_scripts() {

	    // Styles

	    wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/settings.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/font-awesome.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_vertical_tabs_css',		NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap.vertical-tabs.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_slider_css', 			NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-slider.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_iconpicker_css', 		NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-iconpicker.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_formhelpers_css', 		NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/bootstrap-helpers/bootstrap-formhelpers.min.css');

	    // Scripts

		wp_enqueue_media();
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_slider_js', 			NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-slider.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_iconset_js',NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap-helpers/iconset-fontawesome-4.2.0.min.js', array('jquery', self::$prefix . 'bootstrap_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_js', 		NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-iconpicker.js', array('jquery', self::$prefix . 'bootstrap_js', self::$prefix . 'bootstrap_iconpicker_iconset_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_formhelpers_js', 		NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap-helpers/bootstrap-formhelpers.js', array('jquery'));

	    wp_enqueue_style('wp-color-picker');
	    wp_enqueue_script(self::$prefix . 'admin_add_edit_js',				NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/add-edit.js', array('wp-color-picker', 'jquery', 'jquery-ui-tabs', 'jquery-ui-datepicker'), false, true
	    );
	    wp_localize_script(self::$prefix . 'admin_add_edit_js', 'nnr_ppa_add_edit_data', array(
		   'prefix'	=> self::$prefix_dash,
	    ));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function stats_scripts() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');

	    // Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/bootstrap.min.js', array('jquery'));

	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function updates_scripts(){

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/css/nnr-bootstrap.min.css');

	    wp_enqueue_script(self::$prefix . 'updates_js', 					NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL . '/js/updates.js', array('jquery'));
	    wp_localize_script(self::$prefix . 'updates_js', 					'nnr_ppa_updates_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'activate_text'		=> __('Activate', self::$text_domain),
			'deactivate_text'	=> __('Deactivate', self::$text_domain),
			'no_license_key'		=> __('Please add or activate your License Key to get automatic updates.  Without a valid license key you will not receive regular updates. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'expired'				=> __('EXPIRED: This license key has expired.  Please renew your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'activation_error'		=> __('INVALID LICENSE KEY: The license key is not valid please try again. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>.',
			'activation_valid'		=> __('SUCCESS: Your license key is valid.', self::$text_domain),
			'deactivation_valid'	=> __('SUCCESS: This site has been deactivated.', self::$text_domain),
			'deactivation_error'	=> __('DEACTIVATION FAILED: This site could not be deactivated.', self::$text_domain),
		));

	}

	/**
	 * Display the Dashboard page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function dashboard() {

		include_once(NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR . 'controllers/dashboard.php');

	}

	/**
	 * Display the Add New page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function add_edit() {

		include_once(NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR . 'controllers/add-edit.php');

	}

	/**
	 * Display the Stats page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function stats() {

		include_once(NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR . 'controllers/stats.php');

	}

	/**
	 * Display the Updates page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function updates() {

		include_once(NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR . 'controllers/updates.php');

	}

	/**
	 * Perform all the actions with a license
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function license_action() {

		if ( !isset($_POST['license_key']) ) {
			echo '';
			die();
		}

		//Solid Color

	if ( isset($data['args']['background_color']) && $data['args']['background_color'] != '' ) {
		$background .= 'style="background-color:' . $data['args']['background_color'] . ';""';
	}



		// data to send in our API request

		$api_params = array(
			'edd_action'	=> $_POST['license_action'],
			'license' 		=> $_POST['license_key'],
			'item_name' 	=> urlencode( NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_PAGE_PEEL_ADS_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			echo $response;
			die();
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		if ( $_POST['license_action'] == 'activate_license' ) {
			self::update_license_key($_POST['license_key']);
		} else if ( $_POST['license_action'] == 'deactivate_license' && $license_data->license == 'deactivated') {
			self::update_license_key('');
		}

		// decode the license data

		echo $license_data->license;

		die();

	}

	/**
	 * Check if license key is active
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function is_license_active( $license_key ) {

		if ( !isset( $license_key ) ) {
			return false;
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> 'check_license',
			'license' 		=> $license_key,
			'item_name' 	=> urlencode( NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_PAGE_PEEL_ADS_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// decode the license data

		if ( isset($license_data->license) && $license_data->license == 'valid' ) {
			return true;
		} else {
			return false;
		}

	}

	/**
	 * Get the license key
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function get_license_key() {

		// Get the license key from based on WordPress install

		if ( function_exists('is_multisite') && is_multisite() ) {
			$license_key = get_site_option(self::$prefix . 'license_key');
		} else {
			$license_key = get_option(self::$prefix . 'license_key');
		}

		// Check if license key is set

		if ( $license_key === false ) {
			$license_key = '';
		}

		return $license_key;
	}

	/**
	 * Update the license key
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function update_license_key($license_key) {

		if ( isset( $license_key ) ) {

			// Get the license key from based on WordPress install

			if ( function_exists('is_multisite') && is_multisite() ) {

				update_site_option(self::$prefix . 'license_key', $license_key);

			} else {

				update_option(self::$prefix . 'license_key', $license_key);

			}
		}
	}

}

// Item Name

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME', 'Page Peel Ads');
}

// Store URL

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_STORE_URL') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_STORE_URL', 'https://99robots.com');
}

// Minimum PHP version

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_MIN_PHP_VERSION') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_MIN_PHP_VERSION', '5.4.0');
}

// Plugin Name

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_NAME') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));
}

// Plugin directory

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_DIR', plugin_dir_path(__FILE__) );
}

// Plugin url

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_PLUGIN_URL', plugins_url() . '/' . NNROBOTS_PAGE_PEEL_ADS_PLUGIN_NAME);
}

// Plugin verison

if ( !defined('NNROBOTS_PAGE_PEEL_ADS_VERSION_NUM') ) {
	define('NNROBOTS_PAGE_PEEL_ADS_VERSION_NUM', '1.1.3');
}

// EDD Software licensing

if ( !class_exists('EDD_SL_Plugin_Updater') ) {
	include_once( dirname( __FILE__ ) . '/includes/edd-software-licensing-updates/EDD_SL_Plugin_Updater.php' );
}

add_action('wp_ajax_nnr_ppa_license_action', array('NNR_Page_Peel_Ads', 'license_action'));

$edd_updater = new EDD_SL_Plugin_Updater( NNROBOTS_PAGE_PEEL_ADS_STORE_URL , __FILE__, array(
		'version' 	=> NNROBOTS_PAGE_PEEL_ADS_VERSION_NUM,
		'license' 	=> NNR_Page_Peel_Ads::get_license_key(),
		'item_name' => NNROBOTS_PAGE_PEEL_ADS_ITEM_NAME,
		'author' 	=> '99 Robots',
	)
);

endif;
